@@ -56,6 +56,31 @@ NSTDAPI void *nstd_core_slice_last(const NSTDSlice *const slice);
 /// Returns: `NSTDInt32 is_in` - Nonzero if the slice contains `element`.
 NSTDAPI NSTDInt32 nstd_core_slice_contains(const NSTDSlice *const slice, const void *const element);
 
+/// Counts the number of `element`s found in `slice`.
+/// Parameters:
+///     `const NSTDSlice *const slice` - The slice.
+///     `const void *const element` - The element to count.
+/// Returns: `NSTDUSize count` - The number of `element`s in `slice`.
+NSTDAPI NSTDUSize nstd_core_slice_count(const NSTDSlice *const slice, const void *const element);
+
+/// Finds the first `element` in `slice` and returns the index of the element.
+/// Parameters:
+///     `const NSTDSlice *const slice` - The slice.
+///     `const void *const element` - The element to search for.
+/// Returns: `NSTDUSize index` - The index of the element, -1/usize::MAX if not found.
+NSTDAPI NSTDUSize nstd_core_slice_find_first(
+    const NSTDSlice *const slice,
+    const void *const element);
+
+/// Finds the last `element` in `slice` and returns the index of the element.
+/// Parameters:
+///     `const NSTDSlice *const slice` - The slice.
+///     `const void *const element` - The element to search for.
+/// Returns: `NSTDUSize index` - The index of the element, -1/usize::MAX if not found.
+NSTDAPI NSTDUSize nstd_core_slice_find_last(
+    const NSTDSlice *const slice,
+    const void *const element);
+
 /// Checks if a slice starts with another slice.
 /// Parameters:
 ///     `const NSTDSlice *const slice` - The slice.
@@ -80,6 +105,17 @@ NSTDAPI NSTDInt32 nstd_core_slice_ends_with(
 ///     `const void *const element` - The element.
 NSTDAPI void nstd_core_slice_fill(NSTDSlice *const slice, const void *const element);
 
+/// Fills a specific range of a slice with `element`.
+/// NOTE: This function does NOT check that `range` is valid for operating on `slice`.
+/// Parameters:
+///     `NSTDSlice *const slice` - The slice.
+///     `const void *const element` - The element.
+///     `const NSTDURange *const range` - The range of the slice to fill.
+NSTDAPI void nstd_core_slice_fill_range(
+    NSTDSlice *const slice,
+    const void *const element,
+    const NSTDURange *const range);
+
 /// Swaps two elements in a slice.
 /// Parameters:
 ///     `NSTDSlice *const slice` - The slice.
@@ -104,7 +140,7 @@ NSTDAPI void nstd_core_slice_shift_right(NSTDSlice *const slice, const NSTDUSize
 ///     `const NSTDUSize x` - Number of times to shift the slice.
 NSTDAPI void nstd_core_slice_shift_left(NSTDSlice *const slice, const NSTDUSize x);
 
-/// Copies elements from `s1` to `s2`. The slices must be the same size in bytes.
+/// Copies elements from `s2` to `s1`. The slices must be the same size in bytes.
 /// Parameters:
 ///     `NSTDSlice *const s1` - The slice to copy to.
 ///     `const NSTDSlice *const s2` - The slice to copy from.
@@ -116,6 +152,12 @@ NSTDAPI void nstd_core_slice_copy_from_slice(NSTDSlice *const s1, const NSTDSlic
 ///     `NSTDSlice *const s2` - The second slice.
 NSTDAPI void nstd_core_slice_swap_with_slice(NSTDSlice *const s1, NSTDSlice *const s2);
 
+/// Moves bytes from `s2` to `s1`, sets all `s2` bytes to 0.
+/// Parameters:
+///     `NSTDSlice *const s1` - The first slice.
+///     `NSTDSlice *const s2` - The second slice.
+NSTDAPI void nstd_core_slice_move(NSTDSlice *const s1, NSTDSlice *const s2);
+
 #ifdef __cplusplus
 }
 #endif
